Crate kawa

Crate kawa 

Modules

buffer
debug
h1
h2
repr
vecdeque

Macros

compile_lookup
This macro an entire module which contains parsing utilities for a particular rule
make_char_lookup
make_char_map
make_char_predicate
make_char_ranges
make_char_table

Structs

Buffer
Buffer is a pseudo ring buffer specifically designed to store data being parsed
Chunk
ChunkHeader
Flags
Kawa
Intermediate representation for both H1 and H2 protocols
Pair
SliceBuffer
VecDeque

Enums

Block
BodySize
Kind
OutBlock
ParsingErrorKind
ParsingPhase
ParsingPhaseMarker
StatusLine
Store
Version

Traits

AsBuffer
AsBuffer is the trait used by Buffer to oparate on an arbitrary buffer. This is to allow the user to use Kawa over any type as long as it exposes a continious slice of bytes. The previous solution directly used a slice of bytes but it introduces lifetimes. In this approach Buffer owns the underlying buffer.
BlockConverter

Functions

debug_kawa