Modules
Macros
- compile_
lookup - This macro an entire module which contains parsing utilities for a particular rule
- make_
char_ lookup - make_
char_ map - make_
char_ predicate - make_
char_ ranges - make_
char_ table
Structs
- Buffer
- Buffer is a pseudo ring buffer specifically designed to store data being parsed
- Chunk
- Chunk
Header - Flags
- Kawa
- Intermediate representation for both H1 and H2 protocols
- Pair
- Slice
Buffer - VecDeque
Enums
Traits
- AsBuffer
- AsBuffer is the trait used by Buffer to oparate on an arbitrary buffer. This is to allow the user to use Kawa over any type as long as it exposes a continious slice of bytes. The previous solution directly used a slice of bytes but it introduces lifetimes. In this approach Buffer owns the underlying buffer.
- Block
Converter